# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/).

## [Unreleased]

## [0.5.4] - 2025-09-01

[PyPI](https://pypi.org/project/gsffile/0.5.4/)
 · [conda-forge](https://anaconda.org/conda-forge/gsffile)
 · [GitHub release](https://github.com/angelo-peronio/gsffile/releases/tag/v0.5.4)
 · [source](https://github.com/angelo-peronio/gsffile/tree/v0.5.4)


### Added

* Pre-commit hook to check `CITATION.cff`.
* Automated version bumping of `CITATION.cff` and `CHANGELOG.md`.
* Include `CITATION.cff` and `CHANGELOG.md` in source distribution.
* Link changelog to GitHub release notes.

## [0.5.3] - 2025-08-29

### Added

* [Zenodo DOI](https://doi.org/10.5281/zenodo.16998022)
